AsyncData<T> class

The successful state of an asynchronous operation containing value.

Inheritance

Constructors

AsyncData(T value)
const

Properties

hasError bool
Whether this state is AsyncError.
no setteroverride
hashCode int
The hash code for this object.
no setteroverride
hasValue bool
Whether this state is AsyncData.
no setteroverride
isLoading bool
Whether this state is AsyncLoading.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The resolved value.
final
valueOrNull → T?
The value of type T if this is AsyncData, otherwise null.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
when<R>({required R data(T data), required R loading(), required R error(Object error, StackTrace? stackTrace)}) → R
Maps the current state to a value or widget based on the subclass type.
override

Operators

operator ==(Object other) bool
The equality operator.
override