valueOrNull property
T?
get
valueOrNull
The value of type T if this is AsyncData, otherwise null.
Implementation
T? get valueOrNull;
The value of type T if this is AsyncData, otherwise null.
T? get valueOrNull;