canRedo property
bool
get
canRedo
Whether there is at least one undone mutation that can be redone.
Implementation
static bool get canRedo => _redoStack.isNotEmpty;
Whether there is at least one undone mutation that can be redone.
static bool get canRedo => _redoStack.isNotEmpty;