canUndo property
bool
get
canUndo
Whether there is at least one mutation that can be undone.
Implementation
static bool get canUndo => _undoStack.isNotEmpty;
Whether there is at least one mutation that can be undone.
static bool get canUndo => _undoStack.isNotEmpty;