warnAfter property
The duration after which an unclosed batch triggers a warning in debug mode. Defaults to 5 seconds.
Implementation
static Duration warnAfter = const Duration(seconds: 5);
The duration after which an unclosed batch triggers a warning in debug mode. Defaults to 5 seconds.
static Duration warnAfter = const Duration(seconds: 5);