OrbitContextExtension extension

Ergonomic extensions on BuildContext for accessing and watching Orbit stores.

on

Methods

orbit<T extends OrbitStore>([OrbitStoreRef<T>? storeRef]) → T

Available on BuildContext, provided by the OrbitContextExtension extension

Accesses store T from the nearest OrbitScope<T>, falling back to the global singleton if a storeRef is provided, and subscribes this widget context to rebuild on changes.
orbitRead<T extends OrbitStore>([OrbitStoreRef<T>? storeRef]) → T

Available on BuildContext, provided by the OrbitContextExtension extension

Accesses store T without subscribing this widget to rebuilds.