after property
Snapshot taken just after the mutation, if the store overrides OrbitStore.snapshot.
Implementation
final Map<String, Object?>? after;
Snapshot taken just after the mutation, if the store overrides OrbitStore.snapshot.
final Map<String, Object?>? after;