before property
Snapshot taken just before the mutation, if the store overrides OrbitStore.snapshot.
Implementation
final Map<String, Object?>? before;
Snapshot taken just before the mutation, if the store overrides OrbitStore.snapshot.
final Map<String, Object?>? before;