equals property
Custom equality check used to decide whether to rebuild. Defaults
to ==.
Implementation
final bool Function(S previous, S next)? equals;
Custom equality check used to decide whether to rebuild. Defaults
to ==.
final bool Function(S previous, S next)? equals;