inferLabelForTest method
Exposed helper for testing label inference on custom stack traces.
Implementation
@visibleForTesting
String? inferLabelForTest(String? explicitLabel, StackTrace trace) {
return _inferLabel(explicitLabel, trace);
}
Exposed helper for testing label inference on custom stack traces.
@visibleForTesting
String? inferLabelForTest(String? explicitLabel, StackTrace trace) {
return _inferLabel(explicitLabel, trace);
}