call method
T
call()
Returns the singleton instance, creating it on first access.
Implementation
T call() => Orbit.use<T>(_create);
Returns the singleton instance, creating it on first access.
T call() => Orbit.use<T>(_create);