OrbitUndoGroup class
Represents a group of state mutations captured during a single batch execution.
- Inheritance
-
- Object
- OrbitUndoItem
- OrbitUndoGroup
Constructors
-
OrbitUndoGroup({String? label, List<
OrbitUndoEntry> ? entries})
Properties
-
entries
→ List<
OrbitUndoEntry> -
All individual store mutations performed within the batch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
Optional action label of the batch that produced this group.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited