StoreReader class abstract

An interface passed to the compute function in ComputedStore to read other stores.

Constructors

StoreReader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call<T extends OrbitStore>(OrbitStoreRef<T> storeRef) → T
Reads store T using storeRef and registers it as a dependency.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited