snapshot method

Map<String, Object?>? snapshot()
inherited

Override to return a snapshot of your state's fields.

Used by:

  1. Orbit.observe/Orbit.changeLog to report exactly what changed on each mutation.
  2. Stores mixing in Undoable to record state history for Orbit.undo / Orbit.redo.

Implementation

Map<String, Object?>? snapshot() => null;