read<T extends OrbitStore> static method
T?
read<T extends OrbitStore>()
Returns the existing instance of store T, or null if it hasn't
been created yet. Useful when you want to read a store without
accidentally instantiating it.
Implementation
static T? read<T extends OrbitStore>() => _stores[T] as T?;