OrbitBatchWatchdog class

Configuration for the Orbit debug-mode batch watchdog.

If a batch stays open longer than warnAfter (default 5 seconds) in debug mode, onWarning is invoked with a warning message including the captured stack trace from where the batch opened.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

onWarning ↔ void Function(String message)
Callback invoked when a batch stays open longer than warnAfter in debug mode. Defaults to print.
getter/setter pair
warnAfter Duration
The duration after which an unclosed batch triggers a warning in debug mode. Defaults to 5 seconds.
getter/setter pair