snapshot method
Override to return a snapshot of your state's fields.
Used by:
- Orbit.observe/Orbit.changeLog to report exactly what changed on each mutation.
- Stores mixing in Undoable to record state history for Orbit.undo / Orbit.redo.
Implementation
Map<String, Object?>? snapshot() => null;